@@ -57,19 +57,13 @@ class DbDriver(AlertDriver):
                 filter(LoadBalancer.id == lbid).first()
 
             if lb.status == 'ERROR':
-                errmsg = "Load balancer has failed"
-                lb_status = lb.status
+                lb.errmsg = "Load balancer has failed"
             elif degraded:
-                errmsg = "A node on the load balancer has failed"
-                lb_status = 'DEGRADED'
+                lb.errmsg = "A node on the load balancer has failed"
+                lb.status = 'DEGRADED'
             else:
-                errmsg = "A node on the load balancer has recovered"
-                lb_status = 'ACTIVE'
-
-            session.query(LoadBalancer).\
-                filter(LoadBalancer.id == lbid).\
-                update({"status": lb_status, "errmsg": errmsg},
-                       synchronize_session='fetch')
+                lb.errmsg = "A node on the load balancer has recovered"
+                lb.status = 'ACTIVE'
 
             session.commit()
 
@@ -120,10 +114,8 @@ class DbDriver(AlertDriver):
             device.status = 'DELETED'
             lbs = session.query(LoadBalancer).\
                 join(LoadBalancer.devices).\
-                filter(Device.id == device_id).all()
+                filter(Device.id == new_device_id).all()
             for lb in lbs:
-                lb.devices = [new_device]
-                lb.status = "ACTIVE"
                 lb.errmsg = "Load Balancer rebuild on new device"
             logger.info(
                 "Moving IP {0} and marking device {1} for deletion"
